<?php

declare(strict_types=1);

/**
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright Ampache.org, 2001-2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

namespace Ampache\Module\Authentication;

use Ampache\Config\ConfigContainerInterface;
use Ampache\Module\Authentication\Authenticator\DatabaseAuthenticator;
use Ampache\Module\Authentication\Authenticator\ExternalAuthenticator;
use Ampache\Module\Authentication\Authenticator\HttpAuthenticator;
use Ampache\Module\Authentication\Authenticator\LdapAuthenticator;
use Ampache\Module\Authentication\Authenticator\PamAuthenticator;
use Psr\Container\ContainerInterface;

use function DI\factory;

return [
    AuthenticationManagerInterface::class => factory(static function (ContainerInterface $dic): AuthenticationManagerInterface {
        return new AuthenticationManager(
            $dic->get(ConfigContainerInterface::class),
            [
                'mysql' => $dic->get(DatabaseAuthenticator::class),
                'pam' => $dic->get(PamAuthenticator::class),
                'external' => $dic->get(ExternalAuthenticator::class),
                'http' => $dic->get(HttpAuthenticator::class),
                'ldap' => $dic->get(LdapAuthenticator::class),
            ]
        );
    }),
];
