<?php

declare(strict_types=1);

/**
 * vim:set softtabstop=4 shiftwidth=4 expandtab:
 *
 * LICENSE: GNU Affero General Public License, version 3 (AGPL-3.0-or-later)
 * Copyright Ampache.org, 2001-2024
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

namespace Ampache\Module\System\Update\Migration\V3;

use Ampache\Module\System\Dba;
use Ampache\Module\System\Update\Migration\AbstractMigration;

/**
 * Add width and height in table image
 */
final class Migration370028 extends AbstractMigration
{
    protected array $changelog = ['Add width and height in table image'];

    public function migrate(): void
    {
        $sql        = "SELECT `width` FROM `image`";
        $db_results = Dba::read($sql);
        if (!$db_results) {
            $this->updateDatabase("ALTER TABLE `image` ADD COLUMN `width` int(4) unsigned DEFAULT 0 AFTER `image`;");
        }
        $sql        = "SELECT `height` FROM `image`";
        $db_results = Dba::read($sql);
        if (!$db_results) {
            $this->updateDatabase("ALTER TABLE `image` ADD COLUMN `height` int(4) unsigned DEFAULT 0 AFTER `width`;");
        }
    }
}
